@@ -13,7 +13,7 @@ from ruamel.yaml import YAML
 from .context import ScaffoldContext
 from .plugin import ScaffoldPluginContext
 from .plugins import load_plugins
-from .rendering import render_options, render_text
+from .rendering import render_options, render_text, render_value
 from .runtime import ScaffoldRuntime
 
 
@@ -228,7 +228,8 @@ def run(context: ScaffoldContext, options, runtime: ScaffoldRuntime):
 
 
 def execute_scaffold(context: ScaffoldContext, options, runtime: ScaffoldRuntime):
-    tempdir = options.get('temp', tempfile.gettempdir())
+    packages_dir = os.path.realpath(os.path.expanduser('~/.xscaffold/packages'))
+    tempdir = options.get('temp', packages_dir)
     package = options['package']
 
     yaml = YAML()
@@ -246,10 +247,13 @@ def execute_scaffold(context: ScaffoldContext, options, runtime: ScaffoldRuntime
         pkg_dir = fetch_git(runtime, tempdir, package)
     
     scaffold_file = locate_scaffold_file(pkg_dir, name)
-    pkg_dir = os.path.dirname(scaffold_file)
-    sys.path.append(pkg_dir)
     _log.debug('scaffold file: %s', scaffold_file)
 
+    if scaffold_file:
+        pkg_dir = os.path.dirname(scaffold_file)
+    sys.path.append(pkg_dir)
+    
+
     if scaffold_file is not None:
         with open(scaffold_file, 'r') as fhd:
             config = yaml.load(fhd)
@@ -258,9 +262,13 @@ def execute_scaffold(context: ScaffoldContext, options, runtime: ScaffoldRuntime
             'steps': options.get('steps', [{ 'fetch': {} }])
         }
 
+    context.todos.extend(config.get('todos', []))
+    context.notes.extend(config.get('notes', []))
+
     plugin_context = ScaffoldPluginContext(
         config.get('plugins', {})
     )
+
     plugins: list = load_plugins()
     for plugin in plugins:
         plugin.init(plugin_context)
@@ -285,7 +293,7 @@ def execute_steps(context: ScaffoldContext, runtime, plugin_context, steps_conte
     step: dict
     for step in steps:
         if 'if' in step:
-            enabled = render_text(step['if'], context)
+            enabled = render_value(step['if'], context)
             if enabled == False:
                 continue
         if 'group' in step:
@@ -293,7 +301,7 @@ def execute_steps(context: ScaffoldContext, runtime, plugin_context, steps_conte
             execute_steps(context, runtime, plugin_context, steps_context, group_steps)
         elif 'foreach' in step:
             foreach_steps = step['foreach']
-            items = render_text(foreach_steps.get('items', []), context)
+            items = render_value(foreach_steps.get('items', []), context)
             step_id = step.get('id', 'foreach')
             for item in items:
                 context.set_step(step_id, item)
@@ -330,18 +338,19 @@ def fetch_git(runtime, tempdir, package):
         package_name_parts = ['github.com'] + package_name_parts
         package_name = '/'.join(package_name_parts)
     pkg_dir = os.path.join(tempdir, f'{package_name}@{package_version}')
+    _log.debug('using package dir: %s', pkg_dir)
 
     rc = 9999
     if os.path.exists(pkg_dir):
-        runtime.log('{YELLOW}[git] updating %s package...{END}\n' % package)
+        _log.info('[git] updating %s package', package)
         rc = os.system(
                 """(cd {pkg_dir} && git pull >/dev/null 2>&1)""".format(pkg_dir=pkg_dir))
         if rc != 0:
-            runtime.log('{RED}[error]{YELLOW} package %s is having issues, repairing...{END}\n' % package)
+            _log.error('package %s is having issues, repairing', package)
             rm_rf(pkg_dir)
 
     if rc != 0:
-        runtime.log('[git] pulling %s package...' % package + '\n')
+        _log.info('[git] pulling %s package', package)
         rc = os.system(f"""
         git clone https://{package_name} {pkg_dir} >/dev/null 2>&1
         """)
